pub enum Capability {
BuildRs,
Alloc,
Panic,
Time,
Sysinfo,
Stdio,
Thread,
Net,
FS,
Any,
}Expand description
A capability a crate can be granted, or is suspected of having.
Variants
BuildRs
This crate has a custom build step (build.rs)
NOT contagious!
Depending on a crate with a build.rs file does not give you the BuildRs capability.
Alloc
Allocate memory (Box::new, Vec::new, …)
Panic
Call panic!
Time
Read the current time and/or date
Sysinfo
Read environment variables, process info, …
Stdio
Read and write to stdin, stdout, stderr
Thread
Spawn thread
Net
Connect over the network and/or listen for incoming network traffic
FS
Open a file on disk for reading or writing
Any
Anything is possible, including everything else in this enum.
Implementations